# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CryptoService.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Query_pb2 as Query__pb2
import Response_pb2 as Response__pb2
import TransactionResponse_pb2 as TransactionResponse__pb2
import Transaction_pb2 as Transaction__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='CryptoService.proto',
  package='proto',
  syntax='proto3',
  serialized_options=b'\n&com.hederahashgraph.service.proto.java',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13\x43ryptoService.proto\x12\x05proto\x1a\x0bQuery.proto\x1a\x0eResponse.proto\x1a\x19TransactionResponse.proto\x1a\x11Transaction.proto2\xba\x06\n\rCryptoService\x12?\n\rcreateAccount\x12\x12.proto.Transaction\x1a\x1a.proto.TransactionResponse\x12?\n\rupdateAccount\x12\x12.proto.Transaction\x1a\x1a.proto.TransactionResponse\x12@\n\x0e\x63ryptoTransfer\x12\x12.proto.Transaction\x1a\x1a.proto.TransactionResponse\x12>\n\x0c\x63ryptoDelete\x12\x12.proto.Transaction\x1a\x1a.proto.TransactionResponse\x12=\n\x0b\x61\x64\x64LiveHash\x12\x12.proto.Transaction\x1a\x1a.proto.TransactionResponse\x12@\n\x0e\x64\x65leteLiveHash\x12\x12.proto.Transaction\x1a\x1a.proto.TransactionResponse\x12,\n\x0bgetLiveHash\x12\x0c.proto.Query\x1a\x0f.proto.Response\x12\x32\n\x11getAccountRecords\x12\x0c.proto.Query\x1a\x0f.proto.Response\x12\x31\n\x10\x63ryptoGetBalance\x12\x0c.proto.Query\x1a\x0f.proto.Response\x12/\n\x0egetAccountInfo\x12\x0c.proto.Query\x1a\x0f.proto.Response\x12\x37\n\x16getTransactionReceipts\x12\x0c.proto.Query\x1a\x0f.proto.Response\x12\x39\n\x18getFastTransactionRecord\x12\x0c.proto.Query\x1a\x0f.proto.Response\x12\x32\n\x11getTxRecordByTxID\x12\x0c.proto.Query\x1a\x0f.proto.Response\x12\x36\n\x15getStakersByAccountID\x12\x0c.proto.Query\x1a\x0f.proto.ResponseB(\n&com.hederahashgraph.service.proto.javab\x06proto3'
  ,
  dependencies=[Query__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,TransactionResponse__pb2.DESCRIPTOR,Transaction__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_CRYPTOSERVICE = _descriptor.ServiceDescriptor(
  name='CryptoService',
  full_name='proto.CryptoService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=106,
  serialized_end=932,
  methods=[
  _descriptor.MethodDescriptor(
    name='createAccount',
    full_name='proto.CryptoService.createAccount',
    index=0,
    containing_service=None,
    input_type=Transaction__pb2._TRANSACTION,
    output_type=TransactionResponse__pb2._TRANSACTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='updateAccount',
    full_name='proto.CryptoService.updateAccount',
    index=1,
    containing_service=None,
    input_type=Transaction__pb2._TRANSACTION,
    output_type=TransactionResponse__pb2._TRANSACTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='cryptoTransfer',
    full_name='proto.CryptoService.cryptoTransfer',
    index=2,
    containing_service=None,
    input_type=Transaction__pb2._TRANSACTION,
    output_type=TransactionResponse__pb2._TRANSACTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='cryptoDelete',
    full_name='proto.CryptoService.cryptoDelete',
    index=3,
    containing_service=None,
    input_type=Transaction__pb2._TRANSACTION,
    output_type=TransactionResponse__pb2._TRANSACTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='addLiveHash',
    full_name='proto.CryptoService.addLiveHash',
    index=4,
    containing_service=None,
    input_type=Transaction__pb2._TRANSACTION,
    output_type=TransactionResponse__pb2._TRANSACTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='deleteLiveHash',
    full_name='proto.CryptoService.deleteLiveHash',
    index=5,
    containing_service=None,
    input_type=Transaction__pb2._TRANSACTION,
    output_type=TransactionResponse__pb2._TRANSACTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getLiveHash',
    full_name='proto.CryptoService.getLiveHash',
    index=6,
    containing_service=None,
    input_type=Query__pb2._QUERY,
    output_type=Response__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getAccountRecords',
    full_name='proto.CryptoService.getAccountRecords',
    index=7,
    containing_service=None,
    input_type=Query__pb2._QUERY,
    output_type=Response__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='cryptoGetBalance',
    full_name='proto.CryptoService.cryptoGetBalance',
    index=8,
    containing_service=None,
    input_type=Query__pb2._QUERY,
    output_type=Response__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getAccountInfo',
    full_name='proto.CryptoService.getAccountInfo',
    index=9,
    containing_service=None,
    input_type=Query__pb2._QUERY,
    output_type=Response__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getTransactionReceipts',
    full_name='proto.CryptoService.getTransactionReceipts',
    index=10,
    containing_service=None,
    input_type=Query__pb2._QUERY,
    output_type=Response__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getFastTransactionRecord',
    full_name='proto.CryptoService.getFastTransactionRecord',
    index=11,
    containing_service=None,
    input_type=Query__pb2._QUERY,
    output_type=Response__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getTxRecordByTxID',
    full_name='proto.CryptoService.getTxRecordByTxID',
    index=12,
    containing_service=None,
    input_type=Query__pb2._QUERY,
    output_type=Response__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getStakersByAccountID',
    full_name='proto.CryptoService.getStakersByAccountID',
    index=13,
    containing_service=None,
    input_type=Query__pb2._QUERY,
    output_type=Response__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CRYPTOSERVICE)

DESCRIPTOR.services_by_name['CryptoService'] = _CRYPTOSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ConsensusSubmitMessage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import BasicTypes_pb2 as BasicTypes__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ConsensusSubmitMessage.proto',
  package='proto',
  syntax='proto3',
  serialized_options=b'\n\"com.hederahashgraph.api.proto.javaP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1c\x43onsensusSubmitMessage.proto\x12\x05proto\x1a\x10\x42\x61sicTypes.proto\"n\n\x19\x43onsensusMessageChunkInfo\x12\x32\n\x14initialTransactionID\x18\x01 \x01(\x0b\x32\x14.proto.TransactionID\x12\r\n\x05total\x18\x02 \x01(\x05\x12\x0e\n\x06number\x18\x03 \x01(\x05\"\x8e\x01\n%ConsensusSubmitMessageTransactionBody\x12\x1f\n\x07topicID\x18\x01 \x01(\x0b\x32\x0e.proto.TopicID\x12\x0f\n\x07message\x18\x02 \x01(\x0c\x12\x33\n\tchunkInfo\x18\x03 \x01(\x0b\x32 .proto.ConsensusMessageChunkInfoB&\n\"com.hederahashgraph.api.proto.javaP\x01\x62\x06proto3'
  ,
  dependencies=[BasicTypes__pb2.DESCRIPTOR,])




_CONSENSUSMESSAGECHUNKINFO = _descriptor.Descriptor(
  name='ConsensusMessageChunkInfo',
  full_name='proto.ConsensusMessageChunkInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='initialTransactionID', full_name='proto.ConsensusMessageChunkInfo.initialTransactionID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total', full_name='proto.ConsensusMessageChunkInfo.total', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='proto.ConsensusMessageChunkInfo.number', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=167,
)


_CONSENSUSSUBMITMESSAGETRANSACTIONBODY = _descriptor.Descriptor(
  name='ConsensusSubmitMessageTransactionBody',
  full_name='proto.ConsensusSubmitMessageTransactionBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topicID', full_name='proto.ConsensusSubmitMessageTransactionBody.topicID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.ConsensusSubmitMessageTransactionBody.message', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chunkInfo', full_name='proto.ConsensusSubmitMessageTransactionBody.chunkInfo', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=312,
)

_CONSENSUSMESSAGECHUNKINFO.fields_by_name['initialTransactionID'].message_type = BasicTypes__pb2._TRANSACTIONID
_CONSENSUSSUBMITMESSAGETRANSACTIONBODY.fields_by_name['topicID'].message_type = BasicTypes__pb2._TOPICID
_CONSENSUSSUBMITMESSAGETRANSACTIONBODY.fields_by_name['chunkInfo'].message_type = _CONSENSUSMESSAGECHUNKINFO
DESCRIPTOR.message_types_by_name['ConsensusMessageChunkInfo'] = _CONSENSUSMESSAGECHUNKINFO
DESCRIPTOR.message_types_by_name['ConsensusSubmitMessageTransactionBody'] = _CONSENSUSSUBMITMESSAGETRANSACTIONBODY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConsensusMessageChunkInfo = _reflection.GeneratedProtocolMessageType('ConsensusMessageChunkInfo', (_message.Message,), {
  'DESCRIPTOR' : _CONSENSUSMESSAGECHUNKINFO,
  '__module__' : 'ConsensusSubmitMessage_pb2'
  # @@protoc_insertion_point(class_scope:proto.ConsensusMessageChunkInfo)
  })
_sym_db.RegisterMessage(ConsensusMessageChunkInfo)

ConsensusSubmitMessageTransactionBody = _reflection.GeneratedProtocolMessageType('ConsensusSubmitMessageTransactionBody', (_message.Message,), {
  'DESCRIPTOR' : _CONSENSUSSUBMITMESSAGETRANSACTIONBODY,
  '__module__' : 'ConsensusSubmitMessage_pb2'
  # @@protoc_insertion_point(class_scope:proto.ConsensusSubmitMessageTransactionBody)
  })
_sym_db.RegisterMessage(ConsensusSubmitMessageTransactionBody)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import Query_pb2 as Query__pb2
import Response_pb2 as Response__pb2
import TransactionResponse_pb2 as TransactionResponse__pb2
import Transaction_pb2 as Transaction__pb2


class CryptoServiceStub(object):
    """
    Transactions and queries for the Crypto Service
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.createAccount = channel.unary_unary(
                '/proto.CryptoService/createAccount',
                request_serializer=Transaction__pb2.Transaction.SerializeToString,
                response_deserializer=TransactionResponse__pb2.TransactionResponse.FromString,
                )
        self.updateAccount = channel.unary_unary(
                '/proto.CryptoService/updateAccount',
                request_serializer=Transaction__pb2.Transaction.SerializeToString,
                response_deserializer=TransactionResponse__pb2.TransactionResponse.FromString,
                )
        self.cryptoTransfer = channel.unary_unary(
                '/proto.CryptoService/cryptoTransfer',
                request_serializer=Transaction__pb2.Transaction.SerializeToString,
                response_deserializer=TransactionResponse__pb2.TransactionResponse.FromString,
                )
        self.cryptoDelete = channel.unary_unary(
                '/proto.CryptoService/cryptoDelete',
                request_serializer=Transaction__pb2.Transaction.SerializeToString,
                response_deserializer=TransactionResponse__pb2.TransactionResponse.FromString,
                )
        self.addLiveHash = channel.unary_unary(
                '/proto.CryptoService/addLiveHash',
                request_serializer=Transaction__pb2.Transaction.SerializeToString,
                response_deserializer=TransactionResponse__pb2.TransactionResponse.FromString,
                )
        self.deleteLiveHash = channel.unary_unary(
                '/proto.CryptoService/deleteLiveHash',
                request_serializer=Transaction__pb2.Transaction.SerializeToString,
                response_deserializer=TransactionResponse__pb2.TransactionResponse.FromString,
                )
        self.getLiveHash = channel.unary_unary(
                '/proto.CryptoService/getLiveHash',
                request_serializer=Query__pb2.Query.SerializeToString,
                response_deserializer=Response__pb2.Response.FromString,
                )
        self.getAccountRecords = channel.unary_unary(
                '/proto.CryptoService/getAccountRecords',
                request_serializer=Query__pb2.Query.SerializeToString,
                response_deserializer=Response__pb2.Response.FromString,
                )
        self.cryptoGetBalance = channel.unary_unary(
                '/proto.CryptoService/cryptoGetBalance',
                request_serializer=Query__pb2.Query.SerializeToString,
                response_deserializer=Response__pb2.Response.FromString,
                )
        self.getAccountInfo = channel.unary_unary(
                '/proto.CryptoService/getAccountInfo',
                request_serializer=Query__pb2.Query.SerializeToString,
                response_deserializer=Response__pb2.Response.FromString,
                )
        self.getTransactionReceipts = channel.unary_unary(
                '/proto.CryptoService/getTransactionReceipts',
                request_serializer=Query__pb2.Query.SerializeToString,
                response_deserializer=Response__pb2.Response.FromString,
                )
        self.getFastTransactionRecord = channel.unary_unary(
                '/proto.CryptoService/getFastTransactionRecord',
                request_serializer=Query__pb2.Query.SerializeToString,
                response_deserializer=Response__pb2.Response.FromString,
                )
        self.getTxRecordByTxID = channel.unary_unary(
                '/proto.CryptoService/getTxRecordByTxID',
                request_serializer=Query__pb2.Query.SerializeToString,
                response_deserializer=Response__pb2.Response.FromString,
                )
        self.getStakersByAccountID = channel.unary_unary(
                '/proto.CryptoService/getStakersByAccountID',
                request_serializer=Query__pb2.Query.SerializeToString,
                response_deserializer=Response__pb2.Response.FromString,
                )


class CryptoServiceServicer(object):
    """
    Transactions and queries for the Crypto Service
    """

    def createAccount(self, request, context):
        """Creates a new account by submitting the transaction
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateAccount(self, request, context):
        """Updates an account by submitting the transaction
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def cryptoTransfer(self, request, context):
        """Initiates a transfer by submitting the transaction
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def cryptoDelete(self, request, context):
        """Deletes and account by submitting the transaction
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def addLiveHash(self, request, context):
        """(NOT CURRENTLY SUPPORTED) Adds a livehash
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteLiveHash(self, request, context):
        """(NOT CURRENTLY SUPPORTED) Deletes a livehash
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getLiveHash(self, request, context):
        """(NOT CURRENTLY SUPPORTED) Retrieves a livehash for an account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getAccountRecords(self, request, context):
        """Returns all transactions in the last 180s of consensus time for which the given account was the effective payer <b>and</b> network property <tt>ledger.keepRecordsInState</tt> was <tt>true</tt>.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def cryptoGetBalance(self, request, context):
        """Retrieves the balance of an account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getAccountInfo(self, request, context):
        """Retrieves the metadata of an account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getTransactionReceipts(self, request, context):
        """Retrieves the latest receipt for a transaction that is either awaiting consensus, or reached consensus in the last 180 seconds
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getFastTransactionRecord(self, request, context):
        """(NOT CURRENTLY SUPPORTED) Returns the records of transactions recently funded by an account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getTxRecordByTxID(self, request, context):
        """Retrieves the record of a transaction that is either awaiting consensus, or reached consensus in the last 180 seconds
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getStakersByAccountID(self, request, context):
        """(NOT CURRENTLY SUPPORTED) Retrieves the stakers for a node by account id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CryptoServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'createAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.createAccount,
                    request_deserializer=Transaction__pb2.Transaction.FromString,
                    response_serializer=TransactionResponse__pb2.TransactionResponse.SerializeToString,
            ),
            'updateAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.updateAccount,
                    request_deserializer=Transaction__pb2.Transaction.FromString,
                    response_serializer=TransactionResponse__pb2.TransactionResponse.SerializeToString,
            ),
            'cryptoTransfer': grpc.unary_unary_rpc_method_handler(
                    servicer.cryptoTransfer,
                    request_deserializer=Transaction__pb2.Transaction.FromString,
                    response_serializer=TransactionResponse__pb2.TransactionResponse.SerializeToString,
            ),
            'cryptoDelete': grpc.unary_unary_rpc_method_handler(
                    servicer.cryptoDelete,
                    request_deserializer=Transaction__pb2.Transaction.FromString,
                    response_serializer=TransactionResponse__pb2.TransactionResponse.SerializeToString,
            ),
            'addLiveHash': grpc.unary_unary_rpc_method_handler(
                    servicer.addLiveHash,
                    request_deserializer=Transaction__pb2.Transaction.FromString,
                    response_serializer=TransactionResponse__pb2.TransactionResponse.SerializeToString,
            ),
            'deleteLiveHash': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteLiveHash,
                    request_deserializer=Transaction__pb2.Transaction.FromString,
                    response_serializer=TransactionResponse__pb2.TransactionResponse.SerializeToString,
            ),
            'getLiveHash': grpc.unary_unary_rpc_method_handler(
                    servicer.getLiveHash,
                    request_deserializer=Query__pb2.Query.FromString,
                    response_serializer=Response__pb2.Response.SerializeToString,
            ),
            'getAccountRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.getAccountRecords,
                    request_deserializer=Query__pb2.Query.FromString,
                    response_serializer=Response__pb2.Response.SerializeToString,
            ),
            'cryptoGetBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.cryptoGetBalance,
                    request_deserializer=Query__pb2.Query.FromString,
                    response_serializer=Response__pb2.Response.SerializeToString,
            ),
            'getAccountInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.getAccountInfo,
                    request_deserializer=Query__pb2.Query.FromString,
                    response_serializer=Response__pb2.Response.SerializeToString,
            ),
            'getTransactionReceipts': grpc.unary_unary_rpc_method_handler(
                    servicer.getTransactionReceipts,
                    request_deserializer=Query__pb2.Query.FromString,
                    response_serializer=Response__pb2.Response.SerializeToString,
            ),
            'getFastTransactionRecord': grpc.unary_unary_rpc_method_handler(
                    servicer.getFastTransactionRecord,
                    request_deserializer=Query__pb2.Query.FromString,
                    response_serializer=Response__pb2.Response.SerializeToString,
            ),
            'getTxRecordByTxID': grpc.unary_unary_rpc_method_handler(
                    servicer.getTxRecordByTxID,
                    request_deserializer=Query__pb2.Query.FromString,
                    response_serializer=Response__pb2.Response.SerializeToString,
            ),
            'getStakersByAccountID': grpc.unary_unary_rpc_method_handler(
                    servicer.getStakersByAccountID,
                    request_deserializer=Query__pb2.Query.FromString,
                    response_serializer=Response__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'proto.CryptoService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CryptoService(object):
    """
    Transactions and queries for the Crypto Service
    """

    @staticmethod
    def createAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.CryptoService/createAccount',
            Transaction__pb2.Transaction.SerializeToString,
            TransactionResponse__pb2.TransactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def updateAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.CryptoService/updateAccount',
            Transaction__pb2.Transaction.SerializeToString,
            TransactionResponse__pb2.TransactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def cryptoTransfer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.CryptoService/cryptoTransfer',
            Transaction__pb2.Transaction.SerializeToString,
            TransactionResponse__pb2.TransactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def cryptoDelete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.CryptoService/cryptoDelete',
            Transaction__pb2.Transaction.SerializeToString,
            TransactionResponse__pb2.TransactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def addLiveHash(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.CryptoService/addLiveHash',
            Transaction__pb2.Transaction.SerializeToString,
            TransactionResponse__pb2.TransactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteLiveHash(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.CryptoService/deleteLiveHash',
            Transaction__pb2.Transaction.SerializeToString,
            TransactionResponse__pb2.TransactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getLiveHash(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.CryptoService/getLiveHash',
            Query__pb2.Query.SerializeToString,
            Response__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getAccountRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.CryptoService/getAccountRecords',
            Query__pb2.Query.SerializeToString,
            Response__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def cryptoGetBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.CryptoService/cryptoGetBalance',
            Query__pb2.Query.SerializeToString,
            Response__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getAccountInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.CryptoService/getAccountInfo',
            Query__pb2.Query.SerializeToString,
            Response__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getTransactionReceipts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.CryptoService/getTransactionReceipts',
            Query__pb2.Query.SerializeToString,
            Response__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getFastTransactionRecord(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.CryptoService/getFastTransactionRecord',
            Query__pb2.Query.SerializeToString,
            Response__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getTxRecordByTxID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.CryptoService/getTxRecordByTxID',
            Query__pb2.Query.SerializeToString,
            Response__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getStakersByAccountID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.CryptoService/getStakersByAccountID',
            Query__pb2.Query.SerializeToString,
            Response__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
